@@ -16,7 +16,6 @@ from pynfra.modules.db import DB
 from pynfra.modules.ssh_keys import generate_key, remove_hostkeys
 from pynfra.modules.node import Node, NodeAuthException, NodeTimeoutException
 from pynfra.modules.tui import TUI
-from pynfra.sprays.debian_11_torbridge.spray import Debian11Bridge
 
 
 class Pynfra:
@@ -406,11 +405,9 @@ class Pynfra:
         node.copyfile(direction, src, dst)
 
     @need_init
-    def spray(self, hostname):
-        contactinfo = self.__db.getcontactinfo()
-        node = self.__get_server(hostname)
-        s = Debian11Bridge(contactinfo, node, CONFIG.PORTRANGE)
-        s.spray()
+    def recipe(self, recipename):
+        print("hi")
+        pass
 
     def __parse_args(self):
         # if --confdir is set use it
@@ -492,9 +489,9 @@ class Pynfra:
         parser_shell_exec.add_argument('hostname', type=str)
         parser_shell_exec.set_defaults(func='shell')
 
-        parser_spray = subparsers.add_parser('spray', help='initialize the node as a tor bridge')
-        parser_spray.add_argument('hostname', type=str)
-        parser_spray.set_defaults(func='spray')
+        parser_recipe = subparsers.add_parser('recipe', help='specify recipe to load')
+        parser_recipe.add_argument('recipe', type=str)
+        parser_recipe.set_defaults(func='recipe')
 
         args = self.__parser.parse_args()
         return args
@@ -529,16 +526,8 @@ class Pynfra:
             self.shell(self.__args.hostname)
         elif func == "run-all":
             self.exec(None, self.__args.cmd)
-        elif func == "spray":
-            self.spray(self.__args.hostname)
+        elif func == "recipe":
+            self.recipe(self.__args.recipe)
         else:
             self.__parser.print_help()
 
-
-def main():
-    pynfra = Pynfra()
-    pynfra.main()
-
-
-if __name__ == "__main__":
-    main()
